#"@(#) SGeSAP/LX - 12.20.00 - $Rev: 1819 $ - Last modified 02/02/17"
#
# **********************************************************************
# *                                                                    *
# * HPE SGeSAP/LX  `                                                   *
# *                                                                    *
# * Database module dispatcher script                                  *
# *                                                                    *
# *  (c) Copyright 1996-2015 Hewlett-Packard Co.                       *
# *  (c) Copyright 2015-2017 Hewlett Packard Enterprise Co.            *
# *                                                                    *
# *                                                                    *
# * Description: Serviceguard Extension for SAP control logic          *
# *                                                                    *
# * This control script file must not be edited !                      *
# * Any changes made to it will be overwritten when you upgrade to the *
# * next revision of HPE SGeSAP.                                       *
# *                                                                    *
# * Changing this file may lead to unrecoverable package startup       *
# * and/or shutdown problems.                                          *
# *                                                                    *
# **********************************************************************

. ${SGCONF}/scripts/sgesap/sap_control.sh

set -m
trap "wait;sg_log 2 \"Interrupting SGeSAP ${script_name} '${op_code}' runtime steps ...\"; exit 2" 2

case ${op_code} in
  start) 
    check_versions
    cross_check
    init_params_sap_db
    check_debug

    detect_module "sgesap/sapinfra"
    if [ $? -eq 1 ]; then
      detect_module "sgesap/sapextinstance"
      if [ $? -eq 1 ]; then
        dns_sync
      fi
    fi

    if [ -n "${DB_T}" ]; then
      if [ -n "${SRP_NAME}" ]; then
        start_srp  || exit $?
      fi
      start_${DB}_db  || exit $?
    else
      exit 0
    fi

  ;;
  
  stop)
    check_versions
    init_params_sap_db

    if [ -n "${DB_T}" ]; then
      kill_backup ${DBSID}
      stop_${DB}_db  || exit $?
      if [ -n "${SRP_NAME}" ]; then
        stop_srp || exit $?
      fi
    else
      exit 0
    fi
  ;;
  
  validate)
    check_versions
    init_params_sap_db

    static_param_latch DB_SYSTEM
    static_param_latch DB_VENDOR

    SAPVERIFY="${SGSBIN}/sapverify"
    if [ -x "${SAPVERIFY}" ]; then
       ${SAPVERIFY} -p "${SG_PACKAGE}" -sg_op_code "${op_code}" -call "$0"
       rc=$?
       [ ${rc} -gt 0 ] && exit ${rc}
    else
        sg_log 0 "WARNING: Couldn't find or execute ${SAPVERIFY}"
    fi


  ;;
  reconfigure_start)
  ;;
  reconfigure_stop)
  ;;
  *)
    sg_log 0 "ERROR: Runtime called with illegal package mode: '${op_code}'"
    exit 2
  ;;
esac

sg_log 2 "Leaving SGeSAP ${script_name} '${op_code}' runtime steps ..."

