#"@(#) SGeSAP/LX - 12.20.00 - $Rev: 1819 $ - Last modified 02/02/17"
#
# **********************************************************************
# *                                                                    *
# * HPE SGeSAP/LX                                                      *
# *                                                                    *
# * Replicated Database module dispatcher script                       *
# *                                                                    *
# * (c) Copyright 1996-2015 Hewlett-Packard Co.                        *
# * (c) Copyright 2015-2017 Hewlett Packard Enterprise Co.             *
# *                                                                    *
# *                                                                    *
# * Description: Serviceguard Extension for SAP control logic          *
# *                                                                    *
# * This control script file must not be edited !                      *
# * Any changes made to it will be overwritten when you upgrade to the *
# * next revision of HPE SGeSAP.                                       *
# *                                                                    *
# * Changing this file may lead to unrecoverable package startup       *
# * and/or shutdown problems.                                          *
# *                                                                    *
# **********************************************************************


# the following is necessary for the "monitor" param to work
[[ -z "$SGCONF" ]] && . /etc/cmcluster.conf  # for "monitor"
if [[ -z $SG_SCRIPT_LOG_FILE ]]
then
  SG_PACKAGE_NAME=$SG_PACKAGE
  export SG_PACKAGE_NAME
  SG_SCRIPT_LOG_FILE=${SGRUN}/log/${SG_PACKAGE_NAME}.log
  export SG_SCRIPT_LOG_FILE
  if [[ -z $SG_UTILS ]]; then
    SG_UTILS=$SGCONF/scripts/mscripts/utils.sh
  fi
  if [[ -f ${SG_UTILS} ]]; then
    . ${SG_UTILS}
  fi
  PATH=$SGSBIN:/usr/bin:/usr/sbin:/etc:/bin:/sbin  
  export PATH
  sg_source_pkg_env $SG_PACKAGE
  typeset MNAME="monitor,"
fi
# end of preparation for "monitor"

. ${SGCONF}/scripts/sgesap/sap_control.sh

set -m
trap "wait;sg_log 2 \"Interrupting SGeSAP ${script_name} '${op_code}' runtime steps ...\"; exit 2" 2

# Need to check for Sybase toolkit as a prerequiste (at least the script has to be there)
TKIT_SCRIPT_DIR="$SGROOT/sybasetoolkit"
typeset tkitscript="$TKIT_SCRIPT_DIR/hars.sh"
CMD=$tkitscript



case ${op_code} in
  start) 
    check_versions
    cross_check
    init_params_sap_repdb
    check_debug

	if [ -n "${REPDB_T}" ]; then
	  if [[ ! -x  "${tkitscript}" ]]; then
	    ErrLogMsg "${tkitscript} not found"
            ErrLogMsg2 "Usage of this module requires Serviceguard Sybase toolkit installation"
            exit ${ERROR}
	  fi
	  # start_repdb || exit $?
	  #  or
	  . $tkitscript start
	else
	  exit 0
	fi
	
  ;;
  
  stop)
    check_versions
    init_params_sap_repdb

	if [ -n "${REPDB_T}" ]; then
	  if [[ ! -x  "${tkitscript}" ]]; then
	    ErrLogMsg "${tkitscript} not found"
            ErrLogMsg2 "Usage of this module requires Serviceguard Sybase toolkit installation"
		exit ${ERROR}
	  fi
	  # stop_repdb || exit $?
	  #  or
	  . $tkitscript stop
	else
	  exit 0
	fi
  ;;
  
  validate)
    check_versions
    init_params_sap_repdb  || exit ${ERROR}

 #   static_param_latch DB_SYSTEM
 #   static_param_latch DB_VENDOR
 
    if [ -n "${REPDB_T}" ]; then
      if [[ ! -x  "${tkitscript}" ]]; then
        ErrLogMsg "${tkitscript} not found"
        ErrLogMsg2 "Usage of this module requires Serviceguard Sybase toolkit installation"
        exit ${ERROR}
      fi
      . $tkitscript validate 
    fi

    SAPVERIFY="${SGSBIN}/sapverify"
    if [ -x "${SAPVERIFY}" ]; then
        ${SAPVERIFY} -p "${SG_PACKAGE}" -sg_op_code "${op_code}" -call "$0"
        rc=$?
        [ ${rc} -gt 0 ] && exit ${rc}
    else
        sg_log 0 "WARNING: Couldn't find or execute ${SAPVERIFY}"
    fi

  ;;
  reconfigure_start)
  ;;
  reconfigure_stop)
  ;;
  monitor)
    check_versions
    init_params_sap_repdb
    [[ -n "${REPDB_T}" ]] && . $tkitscript rs_monitor
  ;;
  *)
    sg_log 0 "ERROR: Runtime called with illegal package mode: '${op_code}'"
    exit 2
  ;;
esac

sg_log 2 "Leaving SGeSAP ${script_name} '${op_code}' runtime steps ..."

