#"@(#) SGeSAP/LX - 12.20.00 - $Rev: 1819 $ - Last modified 09/18/17"
#
# **********************************************************************
# *                                                                    *
# * HPE SGeSAP/LX                                                      *
# *                                                                    *
# * SAP Netweaver module control script                                *
# *                                                                    *
# * (c) Copyright 1996-2015 Hewlett-Packard Co.                        *
# * (c) Copyright 2015-2017 Hewlett Packard Enterprise Co.             *
# *                                                                    *
# *                                                                    *
# * Description: Serviceguard Extension for SAP control logic          *
# *                                                                    *
# * This control script file must not be edited !                      *
# * Any changes made to it will be overwritten when you upgrade to the *
# * next revision of HPE SGeSAP.                                       *
# *                                                                    *
# * Changing this file may lead to unrecoverable package startup       *
# * and/or shutdown problems.                                          *
# *                                                                    *
# **********************************************************************



########################################################################
#
# Source in the utility functions used by the module scripts
#
########################################################################

typeset script_name=`echo $0|awk '{ print substr ($0,match($0,"[^/]*$")) }'`
typeset op_code=${1}
typeset hname=$(hostname)

HPLAT=`uname`
LX=0
UX=0
case "${HPLAT}" in
  HP-UX)  UX=1 ;;
  Linux)  LX=1 ;;
  *)      echo "Unrecognized platform reported by uname=[`uname`]" ;;
esac

if [ -f /etc/cmcluster.conf ]; then
  . /etc/cmcluster.conf
  if [ $? -ne 0 ]; then
    echo "SGeSAP main: ERROR: Unable to source cluster configuration: /etc/cmcluster.conf"
    exit 2
  fi
else
    echo "SGeSAP main: ERROR: Unable to find cluster configuration: /etc/cmcluster.conf"
    exit 2
fi

SG_UTILS=${SG_UTILS:-${SGCONF}/scripts/mscripts/utils.sh}
SG_LOG_LEVEL=${SG_LOG_LEVEL:-5}
SG_PACKAGE_NAME=${SG_PACKAGE:-}

if [ -e ${SG_UTILS} ]; then
  . ${SG_UTILS}
  if [ $? -ne 0 ]; then
    echo "SGeSAP main: ERROR: Unable to source package utility functions file: ${SG_UTILS}"
    exit 2
  fi
else
  echo "SGeSAP main: ERROR: Unable to find package utility functions file: ${SG_UTILS}"
  exit 2
fi


# The above utils.sh sources in /etc/cmcluster.conf.
# check if $SGCONF and $SGROOT have been set

if [[ -z "$SGCONF" ]]; then
    echo "SGeSAP main: ERROR: \$SGCONF not defined"
    exit 2
fi

if [[ -z "$SGRUN" ]]; then
    echo "SGeSAP main: ERROR: \$SGRUN not defined"
    exit 2
fi

if [[ -z "$SGROOT"  &&  $LX -eq 1 ]]; then
    echo "SGeSAP main: ERROR: \$SGROOT not defined"
    exit 2
fi


########################################################################
#
# Source in the package environment variables
#
########################################################################

if [ -n "$SG_ENV_FILE" ]; then
  sg_source_pkg_env ${op_code}
  if [ $? -eq 1 ]; then
    sg_log 0 "main: ERROR: Unable to retrieve package environment"
    exit 2
  fi
else
  sg_log 0 "main: WARNING: No package environment file"
fi


########################################################################
#
# Globals
#
########################################################################

FUN0_FILE=${FUN0_FILE:-${SGCONF}/scripts/sgesap/sap_functions.sh}
CUS0_FILE=${CUS0_FILE:-${SGCONF}/scripts/sgesap/customer_functions.sh}
CUS1_FILE=${CUS1_FILE:-${SGCONF}/scripts/ext/${SG_PACKAGE_NAME}_customer_functions.sh}
CUS2_FILE=${CUS2_FILE:-${SGCONF}/scripts/${SG_PACKAGE_NAME}/customer_functions.sh}

[[ $UX -eq 1 ]] &&  SRP2_FILE=${SRP1_FILE:-${SGCONF}/${SG_PACKAGE_NAME}/srp_script.incl}

START_WITH_PKG=1
STOP_WITH_PKG=2
RESTART_DURING_FAILOVER=4
STOP_IF_LOCAL_AFTER_FAILOVER=8
RESTART_DURING_CROSS_SUBNET_FAILOVER=16
USER_DEFINED=128


########################################################################
#
# Read additional variables from configuration files
# and include function pools.
#
########################################################################

function get_source
{
  # sg_log 5 "(get_source ${*:+ $*}): TRACE POINT"

  if [ -r $1 ]; then
    sg_log 4 "Found: $1"

    . $1    # display any errors

    if [ $? -ne 0 ]; then
      sg_log 0 "ERROR: Corrupt data in file $1"
      exit 2
    fi

  elif [ "X$2" = "Xcritical" ]; then
    sg_log 0 "ERROR: Missing file $1"
    exit 2
  else
    sg_log 4 "Not used: $1"
  fi
}

########################################################################
#
# print SGeSAP version (=SCCS) and checksum of file
#
# Parameters:
# $1      filename

########################################################################

function print_sccs_and_cksum
{
  typeset F=${1}
  typeset VERSION=""
  typeset CKSUM=""

  if [[ -a ${F} ]]; then 
    [[ $UX -eq 1 ]] && VERSION=`what ${F} | tail -1`
    [[ $LX -eq 1 ]] && VERSION=`grep -m 1 '@(#)' ${F}`

    [[ $UX -eq 1 ]] && CKSUM=`cksum ${F} | cut -d" " -f 1,2`
    [[ $LX -eq 1 ]] && CKSUM=`cksum ${F} |  cut -f 1,2 --delimiter=' '`
    sg_log 4 "Version: ${VERSION} - ${CKSUM}"
  fi

}

########################################################################
#
# "main()"
#
########################################################################

sg_log 2 "Entering SGeSAP ${script_name} '${op_code}' runtime steps ..."
print_sccs_and_cksum ${0}

if [ $# -eq 0 ]; then
  sg_log 0 "SGeSAP main: ERROR: No package mode specified"
  exit 2
fi

get_source $FUN0_FILE critical
print_sccs_and_cksum $FUN0_FILE

get_source $CUS0_FILE critical
print_sccs_and_cksum $CUS0_FILE
 
get_source $CUS1_FILE optional
get_source $CUS2_FILE optional
[[ $UX -eq 1 ]] &&  get_source $SRP2_FILE optional

pkg_is_in_maintenance # set MAINTENANCE_MODE for all SGeSAP package control scripts
